/*******************************************************************************
* File Name: SS_HW.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_SS_HW_H) /* Pins SS_HW_H */
#define CY_PINS_SS_HW_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "SS_HW_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 SS_HW__PORT == 15 && ((SS_HW__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    SS_HW_Write(uint8 value);
void    SS_HW_SetDriveMode(uint8 mode);
uint8   SS_HW_ReadDataReg(void);
uint8   SS_HW_Read(void);
void    SS_HW_SetInterruptMode(uint16 position, uint16 mode);
uint8   SS_HW_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the SS_HW_SetDriveMode() function.
     *  @{
     */
        #define SS_HW_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define SS_HW_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define SS_HW_DM_RES_UP          PIN_DM_RES_UP
        #define SS_HW_DM_RES_DWN         PIN_DM_RES_DWN
        #define SS_HW_DM_OD_LO           PIN_DM_OD_LO
        #define SS_HW_DM_OD_HI           PIN_DM_OD_HI
        #define SS_HW_DM_STRONG          PIN_DM_STRONG
        #define SS_HW_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define SS_HW_MASK               SS_HW__MASK
#define SS_HW_SHIFT              SS_HW__SHIFT
#define SS_HW_WIDTH              1u

/* Interrupt constants */
#if defined(SS_HW__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in SS_HW_SetInterruptMode() function.
     *  @{
     */
        #define SS_HW_INTR_NONE      (uint16)(0x0000u)
        #define SS_HW_INTR_RISING    (uint16)(0x0001u)
        #define SS_HW_INTR_FALLING   (uint16)(0x0002u)
        #define SS_HW_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define SS_HW_INTR_MASK      (0x01u) 
#endif /* (SS_HW__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define SS_HW_PS                     (* (reg8 *) SS_HW__PS)
/* Data Register */
#define SS_HW_DR                     (* (reg8 *) SS_HW__DR)
/* Port Number */
#define SS_HW_PRT_NUM                (* (reg8 *) SS_HW__PRT) 
/* Connect to Analog Globals */                                                  
#define SS_HW_AG                     (* (reg8 *) SS_HW__AG)                       
/* Analog MUX bux enable */
#define SS_HW_AMUX                   (* (reg8 *) SS_HW__AMUX) 
/* Bidirectional Enable */                                                        
#define SS_HW_BIE                    (* (reg8 *) SS_HW__BIE)
/* Bit-mask for Aliased Register Access */
#define SS_HW_BIT_MASK               (* (reg8 *) SS_HW__BIT_MASK)
/* Bypass Enable */
#define SS_HW_BYP                    (* (reg8 *) SS_HW__BYP)
/* Port wide control signals */                                                   
#define SS_HW_CTL                    (* (reg8 *) SS_HW__CTL)
/* Drive Modes */
#define SS_HW_DM0                    (* (reg8 *) SS_HW__DM0) 
#define SS_HW_DM1                    (* (reg8 *) SS_HW__DM1)
#define SS_HW_DM2                    (* (reg8 *) SS_HW__DM2) 
/* Input Buffer Disable Override */
#define SS_HW_INP_DIS                (* (reg8 *) SS_HW__INP_DIS)
/* LCD Common or Segment Drive */
#define SS_HW_LCD_COM_SEG            (* (reg8 *) SS_HW__LCD_COM_SEG)
/* Enable Segment LCD */
#define SS_HW_LCD_EN                 (* (reg8 *) SS_HW__LCD_EN)
/* Slew Rate Control */
#define SS_HW_SLW                    (* (reg8 *) SS_HW__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define SS_HW_PRTDSI__CAPS_SEL       (* (reg8 *) SS_HW__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define SS_HW_PRTDSI__DBL_SYNC_IN    (* (reg8 *) SS_HW__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define SS_HW_PRTDSI__OE_SEL0        (* (reg8 *) SS_HW__PRTDSI__OE_SEL0) 
#define SS_HW_PRTDSI__OE_SEL1        (* (reg8 *) SS_HW__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define SS_HW_PRTDSI__OUT_SEL0       (* (reg8 *) SS_HW__PRTDSI__OUT_SEL0) 
#define SS_HW_PRTDSI__OUT_SEL1       (* (reg8 *) SS_HW__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define SS_HW_PRTDSI__SYNC_OUT       (* (reg8 *) SS_HW__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(SS_HW__SIO_CFG)
    #define SS_HW_SIO_HYST_EN        (* (reg8 *) SS_HW__SIO_HYST_EN)
    #define SS_HW_SIO_REG_HIFREQ     (* (reg8 *) SS_HW__SIO_REG_HIFREQ)
    #define SS_HW_SIO_CFG            (* (reg8 *) SS_HW__SIO_CFG)
    #define SS_HW_SIO_DIFF           (* (reg8 *) SS_HW__SIO_DIFF)
#endif /* (SS_HW__SIO_CFG) */

/* Interrupt Registers */
#if defined(SS_HW__INTSTAT)
    #define SS_HW_INTSTAT            (* (reg8 *) SS_HW__INTSTAT)
    #define SS_HW_SNAP               (* (reg8 *) SS_HW__SNAP)
    
	#define SS_HW_0_INTTYPE_REG 		(* (reg8 *) SS_HW__0__INTTYPE)
#endif /* (SS_HW__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_SS_HW_H */


/* [] END OF FILE */
